﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using AIOUSBNet;  // the namespace exposes the AIOUSB Class interface 

namespace Sample1
{
    public partial class Form1 : Form
    {
        public UInt32 DeviceIndex;

        // Array of controls for GUI updates:
        public TrackBar[] DACOutTrack= new TrackBar[4];
        public Button[] DACOutButton = new Button[4];
        public TextBox[] DACOutText = new TextBox[4];
                
        public Form1()
        {
            InitializeComponent();

            // Arrays of the controls:
            DACOutTrack[0] = trackBar0;
            DACOutTrack[1] = trackBar1;
            DACOutTrack[2] = trackBar2;
            DACOutTrack[3] = trackBar3;
            
            DACOutButton[0] = btnCount0;
            DACOutButton[1] = btnCount1;
            DACOutButton[2] = btnCount2;
            DACOutButton[3] = btnCount3;

            DACOutText[0] = DAC0mv;
            DACOutText[1] = DAC1mv;
            DACOutText[2] = DAC2mv;
            DACOutText[3] = DAC3mv;
            
        }
        
        private void Form1_Load(object sender, EventArgs e)
        {
            DeviceIndex = AIOUSB.diOnly; 
            
            for (int channel = 0; channel < 4; channel++)
            {
                AIOUSB.DACDirect(DeviceIndex, (ushort)channel, 0x8000);
            }
            AIOUSB.DACSetBoardRange(DeviceIndex, 1); // bipolar == 1, unipolar == 0
        }

        private void btnDACWrite_Click(object sender, EventArgs e)
        {           
            Button btnSender = sender as Button;
            UInt32 dacNum = Convert.ToUInt32(btnSender.Tag);

            double mV = DACOutTrack[dacNum].Value / 10;

            AIOUSB.DACDirect(DeviceIndex, (ushort)dacNum, Convert.ToUInt16(mV / 10000 * 0xFFFF + 0x8000));
        }
        
        private void trackBarmV_Scroll(object sender, EventArgs e)
        {
            TrackBar tbarSender = sender as TrackBar;
            UInt32 dacNum = Convert.ToUInt32(tbarSender.Tag);
            int dmV = DACOutTrack[dacNum].Value;
            double mV = dmV / 10.0;
            String TempString = mV.ToString("F1");
            DACOutText[dacNum].Text = TempString;
        }


        private void btnUpdateAll_Click(object sender, EventArgs e)
        {
            ushort[] Data = new ushort[4 * 2]; 
            for (ushort DACNumber = 0; DACNumber < 4; DACNumber++)
            {
                Data[DACNumber * 2] = DACNumber;
                Data[DACNumber * 2 + 1] = (ushort)(DACOutTrack[DACNumber].Value); 
            }

            AIOUSB.DACMultiDirect(DeviceIndex, Data, 4);
        }

        private void DACmV_TextChanged(object sender, EventArgs e)
        {
            TextBox box = sender as TextBox;
            if (box.Text == "") return;
            UInt32 dacNum = Convert.ToUInt32(box.Tag);
            double mV = Convert.ToDouble(box.Text);
            if (mV > 100) mV = 100;
            if (mV < 0) mV = 0;
            box.Text = mV.ToString();

            DACOutTrack[dacNum].Value = Convert.ToInt32( mV * 10);
        }
    }
}
